// set the dimensions and margins of the graph
const margin = { top: 150, right: 350, bottom: 75, left: 75 },
  width = 1000 - margin.left - margin.right,
  height = 700 - margin.top - margin.bottom;

// append the svg object to the body of the page
const svg = d3
  .select("#my_dataviz")
  .append("svg")
  .attr("width", width + margin.left + margin.right)
  .attr("height", height + margin.top + margin.bottom)
  .append("g")
  .attr("transform", `translate(${margin.left},${margin.top})`);

//Graph Title
svg.append("text")
  .attr("x", width / 2)
  .attr("y", -90)
  .attr("text-anchor", "middle")
  .text("Bevarages Manufacture Comparsion ")
  .style("font-size", "25px");

// read the data
d3.csv("data.csv").then((data) => {
  
  // add x axis
  const x = d3.scaleLinear()
    .domain([0, 350]) // Sodium Levels
    .range([0, width]);
  
  //visualize x axis
  svg.append("g")
    .attr("transform", `translate(0, ${height})`)
    .call(d3.axisBottom(x));

  // add x axis label
  svg.append("text")
  	.attr("class","x label")
    .attr("text-anchor", "middle")
    .attr("x", width/2)
    .attr("y", height + 50)
  	.style("font-size", "20px")
    .text("glucose");

  // add y axis
	const y = d3.scaleLinear()
		.domain([0, 100])
		.range([height, 0])
	
  //visualize y axis
	svg.append("g")
		.call(d3.axisLeft(y));

  // add y axis label:
  svg.append("text")
    .attr("text-anchor", "middle")
    .attr("x", -height / 2)
    .attr("y", -50)
    .text("Bevarages Rating")
  	.style("font-size", "20px")
    .attr("transform", "rotate(-90)");


  // add a scale for bubble size
  const z = d3.scaleLinear()
    .domain([0, 150]) // max calorie size
    .range([0, 23]);

  // add a scale for bubble color
  const myColor = d3.scaleOrdinal()
    .domain(["s", "p", "m", "t", "f", "c","d"])
    .range(d3.schemeSet1);

  // add Bubbles
  svg.append("g")
    .selectAll("dot")
    .data(data)
    .join("circle")
    .attr("class", "bubbles")
    .attr("cx", (d) => x(d.sodium)) // x-axis: Sodium Levels
    .attr("cy", (d) => y(d.rating)) // y-axis: Cereal Rating
    .attr("r", (d) => z(d.calories))
    .style("fill", (d) => myColor(d.bev))
    .style("opacity", "0.7")
    .attr("stroke", "black");

  //Bubble size legend
  const valuesToShow = [50, 100, 150];

  //circle sizes
  svg.selectAll("legend")
    .data(valuesToShow)
    .join("circle")
    .attr("cx", (d) => z(d) * 6 + 640)
    .attr("cy", (d) => height - 150 - z(d))
    .attr("r", (d) => z(d))
    .style("fill", "grey")
    .style("opacity", "0.7")
    .attr("stroke", "black");

  //Size number labels
  svg.append("text")
    .attr("x", 685)
    .attr("y", 355)
    .text("50")
    .style("font-size", 15)
    .attr("text-anchor", "middle");

  svg.append("text")
    .attr("x", 735)
    .attr("y", 355)
    .text("100")
    .style("font-size", 15)
    .attr("text-anchor", "middle");

  svg.append("text")
    .attr("x", 785)
    .attr("y", 355)
    .text("150")
    .style("font-size", 15)
    .attr("text-anchor", "middle");

  // Size legend title
  svg.append("text")
    .attr("x", 740)
    .attr("y", 400)
    .text("Calorie Size")
    .style("font-size", 20)
    .attr("text-anchor", "middle");

  //Bubble color legend
  const size = 20;
  const newgroups = ["sprite", "pepsi", "maaza", "thumsup", "fanta", "coke","dew"];
  const myLabelColor = d3.scaleOrdinal()
    .domain(["s", "p", "m", "t", "f", "c","d"])

    .range(d3.schemeSet1);

  //add colored dots for legend
  svg.selectAll("myrect")
    .data(newgroups)
    .join("circle")
    .attr("cx", 650)
    .attr("cy", (d, i) => 10 + i * (size + 7))
    .attr("r", 5)
    .style("fill", (d) => myLabelColor(d))
    .style("opacity", "0.7")
    .attr("stroke", "black");

  // add labels beside colored dots
  svg.selectAll("mylabels")
    .data(newgroups)
    .enter()
    .append("text")
    .attr("x", 680)
    .attr("y", (d, i) => 10 + i * (size + 7))
    .style("fill", (d) => myLabelColor(d))
    .text((d) => d)
    .attr("text-anchor", "left")
    .style("alignment-baseline", "middle");

  //color legend title
  svg.append("text")
    .attr("x", 740)
    .attr("y", -20)
    .text("Bevarages:")
    .style("font-size", 18)
    .attr("text-anchor", "middle");
});
